Tüm Ürünler
Search
Belge Merkezi

Elastic Compute Service:Instance logon credentials

Son Güncelleme:Sep 30, 2026

Bir ECS örneğinde varsayılan bir parola bulunmaz. Parolanızı unutursanız sıfırlayabilirsiniz. Bir örnek oluştururken bir oturum açma adı belirtmezseniz sistem varsayılan bir ad atar.


İşletim sistemi


Varsayılan kullanıcı adı


Açıklama


Linux


root


Linux işletim sisteminin süper kullanıcısıdır.


Windows


Administrator


Windows işletim sisteminin yönetici hesabıdır.

Önemli

root kullanıcısı yükseltilmiş izinlere sahiptir; doğrudan kullanılması güvenlik riski oluşturur. Hassas işlemler için ecs-user hesabını kullanmanızı ve geçici olarak root ayrıcalıkları elde etmek üzere sudo komutunu çalıştırmanızı öneririz.

2. Parola yönetimi

2,1 Unutulan parolayı sıfırlama

Çevrimiçi parola sıfırlama işlemi örnek yeniden başlatma gerektirmez. Öncelikle bu yöntemi denemenizi öneririz.

Çevrimiçi sıfırlama (yeniden başlatma gerekmez)

Not

Çevrimiçi parola sıfırlama işlemini gerçekleştirebilmeniz için Cloud Assistant Agent'ın örnekte yüklü olması gerekir. Daha fazla bilgi için bkz. Cloud Assistant Agent durumunu kontrol etme ve Cloud Assistant Agent'ı yükleme.

  1. ECS konsolu - Örnekler sayfasına gidin, bir bölge ve kaynak grubu seçin, ardından hedef örneği bulun.

  2. Reset Password iletişim kutusunu açmak için aşağıdaki talimatları uygulayın.

    image

  3. Reset Password iletişim kutusunda aşağıdaki parametreleri yapılandırın ve OK seçeneğine tıklayın. Diğer parametreleri varsayılan değerlerinde bırakın.

    • New Password/Confirm Password: Örnek için güçlü bir parola girin. Güçlü bir parola büyük harf, küçük harf, rakam ve özel karakter içermelidir.

    • Parola Sıfırlama Yöntemi: Çevrimiçi Parola Sıfırlama seçeneğini belirleyin.

      Önemli

      Online Password Reset seçeneğini seçemiyorsanız çevrimdışı parola sıfırlama (yeniden başlatma gerekir) yöntemini kullanın.

    Parola sıfırlama işlemi başarısız olursa çevrimdışı parola sıfırlama (yeniden başlatma gerekir) yöntemini kullanın.

Çevrimdışı sıfırlama (yeniden başlatma gerekir)

Önemli

Çevrimdışı parola sıfırlama işlemi yalnızca örneği yeniden başlattıktan sonra etkili olur. Örneği yeniden başlatmak hizmetlerinizi kesintiye uğratabilir. Bu işlemi yoğun olmayan saatlerde yapmanızı öneririz.

  1. ECS konsolu - Örnekler sayfasına gidin, bir bölge ve kaynak grubu seçin, ardından hedef örneği bulun.

  2. Reset Password iletişim kutusunu açmak için aşağıdaki talimatları uygulayın.

    image

  3. Reset Password iletişim kutusunda aşağıdaki parametreleri yapılandırın ve OK seçeneğine tıklayın.

    • New Password/Confirm Password: Örnek için güçlü bir parola girin. Güçlü bir parola büyük harf, küçük harf, rakam ve özel karakter içermelidir.

    • Parola Sıfırlama Yöntemi: Çevrimdışı Parola Sıfırlama seçeneğini belirleyin.

  4. Örneği yeniden başlatın.

    Parola sıfırlama işlemi yalnızca örnek yeniden başlatıldıktan sonra etkili olur. Hizmet kesintilerini en aza indirmek için yeniden başlatmayı yoğun olmayan saatlerde yapın.

  5. VNC kullanarak örneğe bağlanma ve oturum açma.

    Başarılı bir VNC oturum açma işlemi, parolanın işletim sisteminde sıfırlandığını gösterir.

    Workbench gibi araçlarla oturum açamazsanız ancak VNC kullanarak örnekte başarılı şekilde oturum açabilirseniz parola sıfırlanmış demektir. Oturum açma hatası SSH yapılandırması sorunundan kaynaklanıyor olabilir. Sorun giderme için bkz. Linux örnekleri için bağlantı sorunlarını giderme .

2,2 Parola değiştirme

Öncelikle konsolda çevrimiçi olarak parolayı sıfırlamayı denemenizi öneririz.

Çevrimiçi parola sıfırlama

Not

Çevrimiçi parola sıfırlama işlemini gerçekleştirebilmeniz için Cloud Assistant Agent'ın örnekte yüklü olması gerekir. Daha fazla bilgi için bkz. Cloud Assistant Agent durumunu kontrol etme ve Cloud Assistant Agent'ı yükleme.

  1. ECS konsolu - Örnekler sayfasına gidin, bir bölge ve kaynak grubu seçin, ardından hedef örneği bulun.

  2. Konsol sürümünüze göre Reset Password iletişim kutusunu açın.

    image

  3. Reset Password iletişim kutusunda aşağıdaki parametreleri yapılandırın ve OK seçeneğine tıklayın. Diğer parametreleri varsayılan değerlerinde bırakın.

    • New Password/Confirm Password: Örnek için güçlü bir parola girin. Güçlü bir parola büyük harf, küçük harf, rakam ve özel karakter içermelidir.

    • Parola Sıfırlama Yöntemi: Çevrimiçi Parola Sıfırlama seçeneğini belirleyin.

      Önemli

      Online Password Reset seçeneğini seçemiyorsanız parolayı örnekte manuel olarak değiştirin.

    Parola sıfırlama işlemi başarısız olursa parolayı örnekte manuel olarak değiştirin.

Manuel parola değiştirme

Windows örneği

Aşağıdaki örnekte Windows Server 2019 örneği kullanılmaktadır:

  1. Workbench kullanarak Windows örneğinde oturum açma.

  2. Başlat simgesine image.png sağ tıklayın, Run seçeneğine tıklayın, compmgmt.msc girin ve ardından Enter tuşuna basın.

  3. Sol gezinme bölmesinde Computer Management > Local Users and Groups > User yolunu izleyin.

  4. Parolasını değiştirmek istediğiniz kullanıcının adına (örneğin Administrator) sağ tıklayın ve ardından Set Password seçeneğine tıklayın.

  5. Set Password for Administrator iletişim kutusunda Continue seçeneğine tıklayın ve ardından New Password ve Confirm alanlarına yeni bir parola girin.

    Önemli

    Büyük harf, küçük harf, rakam ve özel karakter içeren güçlü bir parola kullanın.

  6. OK seçeneğine tıklayın. Parolanın değiştirildiğini belirten bir onay mesajı görüntülenir.

Linux örneği

Aşağıdaki örnekte Alibaba Cloud Linux 3 örneği kullanılmaktadır:

  1. Workbench kullanarak Linux örneğinde oturum açma.

  2. Aşağıdaki komutu çalıştırın:

    <username> ifadesini parolasını değiştirmek istediğiniz kullanıcıyla değiştirin.
    sudo passwd <username>
  3. Yeni parolayı girin ve Enter tuşuna basın. Yeni parolayı tekrar girin ve tekrar Enter tuşuna basın.

    Önemli

    Büyük harf, küçük harf, rakam ve özel karakter içeren güçlü bir parola kullanın.

  4. Parola başarıyla değiştirildiğinde aşağıdaki mesaj döndürülür:

    passwd: all authentication tokens updated successfully.

2. Anahtar çifti yönetimi

Bir örnek oluştururken Alibaba Cloud'da oluşturduğunuz veya içe aktardığınız bir anahtar çiftini oturum açmak için iliştirebilirsiniz. Bir örnek oluştururken bir anahtar çifti iliştirmezseniz anahtar çiftini örneğe iliştirmeniz gerekir.

Anahtar çifti güvenli bir oturum açma kimlik bilgisidir. Brute-force ve sözlük saldırılarına karşı örneğinizi korumanıza yardımcı olur. İki bölümden oluşur: Örnekte depolanan bir genel anahtar ve sizin sakladığınız bir özel anahtar. Bir örnekte oturum açmak için kimlik doğrulama amacıyla özel anahtarı sağlamalısınız.

Anahtar çifti kimlik doğrulamasının çalışma şekli

Aşağıdaki figür basitleştirilmiş Secure Shell (SSH) anahtar çifti kimlik doğrulama sürecini göstermektedir. Bir istemci oturum açma isteği gönderdikten sonra sunucu genel anahtarla rastgele bir dizeyi şifreler. İstemci bu dizeyi özel anahtarla çözer ve sunucuya geri gönderir. Sunucu daha sonra iki dizenin eşleşip eşleşmediğini kontrol ederek istemciyi doğrular.

image
Bir Windows örneğinde anahtar çifti kullanmak için örnekte SSH hizmetini etkinleştirin. Anahtar çiftini konsoldan yönetemezsiniz.

2,1 Anahtar çifti oluşturma veya içe aktarma

Konsol

Anahtar çifti oluşturma

  1. ECS konsolu - Anahtar Çiftleri sayfasına gidin. Sol üst köşeden bir bölge ve bir kaynak grubu seçin.

    ECS örneklerine yalnızca aynı bölgedeki anahtar çiftleri iliştirilebilir.
  2. Create Key Pair seçeneğine tıklayın. Oluşturma yöntemini Auto-create olarak ayarlayın.

  3. OK seçeneğine tıklayın.

    Anahtar çifti oluşturulduktan sonra tarayıcı özel anahtar dosyasını (key_pair_name.pem) yerel bilgisayarınıza otomatik olarak indirir.

Anahtar çifti içe aktarma

İçe aktarılan anahtar çiftleri için desteklenen şifreleme yöntemleri

  • rsa

  • dsa

  • ssh-rsa

  • ssh-dss

  • ecdsa

  1. Özel anahtardan genel anahtarı görüntüleme

    Yerel makine Linux veya macOS

    Mevcut bir özel anahtar dosyasından genel anahtarı çıkarmak ve görüntülemek için ssh-keygen komutunu kullanın.

    , özel anahtar dosyasının yoludur; örneğin /path_to_key_pair/my-key-pair.pem .
    ssh-keygen -y -f <path_to_key_pair>

    Genel anahtar döndürülür:

    ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABA****+GF9q7rhc6vYrExwT4WU4fsaRcVXGV2Mg9RHex21hl1au77GkmnIgukBZjywlQOT4GDdsJy2nBOdJPrCEBIPxxxxxxxxxx/fctNuKjcmMMOA8YUT+sJKn3l7rCLkesE+S5880yNdRjBiiUy40kyr7Y+fqGVdSOHGMXZQPpkBtojcxxxxxxxxxxx/htEqGa/Jq4fH7bR6CYQ2XgH/hCap29Mdi/G5Tx1nbUKuIHdMWOPvjxxxxxxxxxx+lHtTGiAIRG1riyNRVC47ZEVCxxxxxx

    Yerel makine Windows

    Genel anahtarı görüntülemek için aşağıdakileri yapın:

    1. PuTTYgen uygulamasını başlatın.

    2. Load seçeneğine tıklayın.

    3. Bir .ppk veya .pem dosyası seçin.

      PuTTYgen genel anahtarı görüntüler.

  2. Anahtar çiftini (genel anahtar) içe aktarma

    1. ECS konsolu - Anahtar Çiftleri sayfasına gidin. Sol üst köşeden bir bölge seçin.

      ECS örneklerine yalnızca aynı bölgedeki anahtar çiftleri iliştirilebilir.
    2. Create Key Pair seçeneğine tıklayın. Oluşturma yöntemini Import olarak ayarlayın ve Public Key: değerini sağlayın.

    3. İçe aktarmayı tamamlamak için OK seçeneğine tıklayın.

API

2,2 Anahtar çifti iliştirme veya değiştirme

Konsol

Not

Konsolda Linux örnekleri için anahtar çiftlerini iliştirebilir, ayırabilir ve değiştirebilirsiniz.

Örnek oluştururken anahtar çifti iliştirme

Özel başlatma şablonunu kullanarak bir örnek oluştururken Logon Credential seçeneğini Key Pair olarak ayarlayın ve ardından mevcut bir Key Pair seçin.

Anahtar çifti iliştirme veya değiştirme

Önemli
  • Konsolda anahtar çifti iliştirmek veya değiştirmek, değişikliğin etkili olması için örneği yeniden başlatmanızı gerektirir. Yeniden başlatma örnekteki hizmetleri kesintiye uğratabilir. Yeniden başlatma zamanını buna göre planlayın.

  • Konsolda bir örneğe en fazla bir anahtar çifti iliştirebilirsiniz. Birden çok anahtar çifti iliştirmek için örnek içinde manuel olarak iliştirin.

Konsolda iliştirme veya değiştirme (yeniden başlatma gerekir)

ECS konsolu - Örnekler sayfasına gidin. Sol üst köşeden bir bölge ve bir kaynak grubu seçin. Hedef ECS örneğini bulun ve aşağıdaki talimatları uygulayın:

Actions sütununda Bind Key Pair seçeneğine tıklayın. Mevcut bir anahtar çifti seçin ve OK seçeneğine tıklayın. Değişiklik örneği yeniden başlattıktan sonra etkili olur.

image

Örnekte manuel iliştirme (yeniden başlatma gerekmez)

  1. Anahtar çifti oluşturma

    Anahtar çifti oluşturma adımları kullanılan araca göre değişir. Bu bölümde ssh-keygen aracı örnek olarak kullanılmıştır.

    Bir anahtar çifti oluşturmak için aşağıdaki komutu girin.

    ssh-keygen -t rsa -b 2048 -f id_rsa

    Parametreler:

    • -t rsa: Anahtar türü rsa şeklindedir.

    • -b 2048: Anahtar uzunluğu 2048 bittir.

    • -f id_rsa: Anahtar çifti için dosya adı ve kaydetme konumu.

    Sistem sizden bir parola girmenizi ister. Parola özel anahtarınızı korur. Parola belirlemek önerilen bir güvenlik önlemidir. Bir parolaya ihtiyacınız yoksa devam etmek için Enter tuşuna basın.

    Komut çalıştıktan sonra geçerli dizinde iki dosya oluşturulur:

    • id_rsa: Özel anahtarınız.

    • id_rsa.pub: Genel anahtarınız.

    Önemli

    Özel anahtarınızı güvende tutun. Başkalarıyla paylaşmayın.

  2. Genel anahtarı örneğe iliştirme

    Workbench kullanarak örnekte oturum açtıktan sonra aşağıdaki adımları uygulayın.

    Root kullanıcı için genel anahtar iliştirme yordamı root olmayan kullanıcıdan farklıdır. İhtiyaçlarınıza göre yordamı seçin.

    Root kullanıcı için genel anahtarı ayarlama

    1. authorized_keys yapılandırma dosyasını oluşturun.

      /root/.ssh dizini veya authorized_keys dosyası yoksa bunları oluşturmak için aşağıdaki komutları çalıştırın.

      sudo mkdir /root/.ssh
      sudo touch /root/.ssh/authorized_keys
    2. Genel anahtarı ekleyin.

      authorized_keys dosyasını Vim gibi bir metin düzenleyiciyle açın.

      sudo vim /root/.ssh/authorized_keys

      Genel anahtarınızı dosyaya yapıştırın. Birden çok genel anahtar ekleyebilirsiniz. Her genel anahtar yeni bir satırda olmalıdır. İşlemi tamamladıktan sonra dosyayı kaydedin ve kapatın.

    3. Dosya izinlerini ayarlayın.

      SSH sıkı izin ayarları gerektirir. Yanlış izinler SSH oturum açma işleminin başarısız olmasına neden olur.

      Doğru izinleri ayarlamak için aşağıdaki komutları çalıştırın.

      sudo chmod 700 /root/.ssh
      sudo chmod 600 /root/.ssh/authorized_keys

    Root olmayan kullanıcı için genel anahtarı ayarlama

    1. authorized_keys yapılandırma dosyasını oluşturun.

      /home/<username>/.ssh dizini veya authorized_keys dosyası yoksa bunları oluşturmak için aşağıdaki komutları çalıştırın.

      Komutlarda <username> genel anahtarı iliştirmek istediğiniz kullanıcının kullanıcı adıdır.
      sudo mkdir /home/<username>/.ssh
      sudo touch /home/<username>/.ssh/authorized_keys
    2. Genel anahtarı ekleyin.

      authorized_keys dosyasını Vim gibi bir metin düzenleyiciyle açın.

      sudo vim /home/<username>/.ssh/authorized_keys

      Genel anahtarınızı dosyaya yapıştırın. Birden çok genel anahtar ekleyebilirsiniz. Her genel anahtar yeni bir satırda olmalıdır. İşlemi tamamladıktan sonra dosyayı kaydedin ve kapatın.

    3. Dosya izinlerini ayarlayın.

      SSH sıkı izin ayarları gerektirir. Yanlış izinler SSH oturum açma işleminin başarısız olmasına neden olur.

      Doğru izinleri ayarlamak için aşağıdaki komutları çalıştırın.

      sudo chown -R <username>:<username> /home/<username>/.ssh
      sudo chmod 700 /home/<username>/.ssh
      sudo chmod 600 /home/<username>/.ssh/authorized_keys
  3. SSH hizmeti için genel anahtar kimlik doğrulamasını etkinleştirme

    Genel anahtarı yapılandırdıktan sonra sunucuda SSH genel anahtar kimlik doğrulamasını etkinleştirmeniz gerekir. Aksi takdirde anahtar tabanlı oturum açma başarısız olur.

    1. SSH yapılandırma dosyasını /etc/ssh/sshd_config yedekleyin.

      sudo cp /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
    1. /etc/ssh/sshd_config dosyasını Vim gibi bir metin düzenleyiciyle açın. PubkeyAuthentication parametresini bulun ve yes olarak ayarlayın. Bu işlem genel anahtar kimlik doğrulamasını etkinleştirir.

      sudo vim /etc/ssh/sshd_config
    2. Değişikliklerin uygulanması için SSH hizmetini yeniden başlatın.

      Alibaba Cloud Linux 3 için örnek:

      sudo systemctl restart sshd
      Ubuntu veya Debian gibi bazı işletim sistemlerinde SSH hizmeti sshd yerine ssh olarak adlandırılır. Komutu gerektiği şekilde ayarlayın.
      Önemli

      Örneğe SSH üzerinden bağlıysanız hizmeti yeniden başlatmak bağlantınızı kesebilir. Hizmet yeniden başladıktan sonra tekrar bağlanabilirsiniz.

API

Not

API işlemlerini kullanarak anahtar çiftlerini yalnızca Linux örnekleri için iliştirebilir, değiştirebilir veya ayırabilirsiniz.

  • Örnek oluştururken anahtar çifti ayarlama: Bir örnek oluşturmak için RunInstances çağrısı yaptığınızda KeyPairName değerini anahtar çiftinin adına ayarlayın.

  • Anahtar çifti iliştirme veya değiştirme: AttachKeyPair çağrısı yapın ve anahtar çifti adı KeyPairName ile örnek ID'lerini InstanceIds belirtin.

  • Anahtar çiftini ayırma: DetachKeyPair çağrısı yapın ve anahtar çifti adı KeyPairName ile örnek ID'lerini InstanceIds belirtin.

2,3 Anahtar çiftini ayırma

Önemli

Konsolda anahtar çiftini ayırmak, değişikliğin etkili olması için örneği yeniden başlatmanızı gerektirir. Yeniden başlatma örnekteki hizmetleri kesintiye uğratabilir. Yeniden başlatma zamanını buna göre planlayın.

Konsolda ayırma (yeniden başlatma gerekir)

ECS konsolu - Örnekler sayfasına gidin. Sol üst köşeden bir bölge ve bir kaynak grubu seçin. Hedef ECS örneğini bulun ve aşağıdaki talimatları uygulayın:

Actions sütununda Unbind Key Pair seçeneğine tıklayın ve ardından Unbind seçeneğine tıklayın. Değişiklik örneği yeniden başlattıktan sonra etkili olur.

image

Örnekte manuel ayırma (yeniden başlatma gerekmez)

Genel anahtarını authorized_keys dosyasından kaldırarak bir anahtar çiftini örnek içinde manuel olarak ayırabilirsiniz. authorized_keys dosyasının yolu farklı kullanıcılar için değişir:

  • root kullanıcısı: /root/.ssh/authorized_keys

  • root olmayan kullanıcı: /home/<username>/.ssh/authorized_keys

    burada <username> kullanıcının kullanıcı adıdır.

2,4 Anahtar çiftini silme

Konsol

Önemli

Bir örneğe iliştirilmiş bir anahtar çiftini silemezsiniz.

  1. ECS konsolu - Anahtar Çiftleri sayfasına gidin. Sol üst köşeden bir bölge ve bir kaynak grubu seçin.

  2. Silmek istediğiniz anahtar çiftini bulun. Actions sütununda Delete seçeneğine tıklayın. Bu işlem anahtar çiftini siler.

API

DeleteKeyPairs çağrısı yapın ve KeyPairNames değerini silmek istediğiniz anahtar çiftlerinin ad listesine ayarlayın.

3. Çok kullanıcılı uzaktan oturum açma

Bir ECS örneği için birden çok kullanıcı ayarlamak üzere standart bir kullanıcı oluşturmak ve uzaktan erişimi etkinleştirmek için aşağıdaki adımları uygulayın.

Linux sistemleri

Workbench kullanarak örnekte oturum açın ve aşağıdaki gibi bir kullanıcı oluşturun:

  1. Kullanıcı oluşturma

    Komuttaki ifadesini oluşturulacak kullanıcının kullanıcı adıyla değiştirin. Örneğin exampleuser adlı bir kullanıcı oluşturmak için sudo useradd -m exampleuser komutunu çalıştırın.
    sudo useradd -m <username>
  2. Parola veya anahtar çifti ayarlama

    Anahtar çifti iliştirme

    1. Yerel makinenizde bir anahtar çifti dosyası oluşturun.

      Önemli

      Güvenlik nedeniyle örnekte ssh-keygen kullanarak anahtar çifti oluşturmayın. Oluşturulan özel anahtarı bağlanacağınız ECS örneğinde kaydetmeyin.

      Anahtar çifti oluşturma adımları kullanılan araca göre değişir. Bu bölümde ssh-keygen aracı örnek olarak kullanılmıştır.

      Bir anahtar çifti oluşturmak için aşağıdaki komutu girin.

      ssh-keygen -t rsa -b 2048 -f id_rsa

      Parametreler:

      • -t rsa: Anahtar türü rsa şeklindedir.

      • -b 2048: Anahtar uzunluğu 2048 bittir.

      • -f id_rsa: Anahtar çifti için dosya adı ve kaydetme konumu.

      Sistem sizden bir parola girmenizi ister. Parola özel anahtarınızı korur. Parola belirlemek önerilen bir güvenlik önlemidir. Bir parolaya ihtiyacınız yoksa devam etmek için Enter tuşuna basın.

      Komut çalıştıktan sonra geçerli dizinde iki dosya oluşturulur:

      • id_rsa: Özel anahtarınız.

      • id_rsa.pub: Genel anahtarınız.

      Önemli

      Özel anahtarınızı güvende tutun. Başkalarıyla paylaşmayın.

    2. Genel anahtarı kullanıcıya iliştirme.

      1. authorized_keys yapılandırma dosyasını oluşturun.

        /home/<username>/.ssh dizini veya authorized_keys dosyası yoksa bunları oluşturmak için aşağıdaki komutları çalıştırın.

        Komutlarda <username> genel anahtarı iliştirmek istediğiniz kullanıcının kullanıcı adıdır.
        sudo mkdir /home/<username>/.ssh
        sudo touch /home/<username>/.ssh/authorized_keys
      2. Genel anahtarı ekleyin.

        authorized_keys dosyasını Vim gibi bir metin düzenleyiciyle açın.

        sudo vim /home/<username>/.ssh/authorized_keys

        Genel anahtarınızı dosyaya yapıştırın. Birden çok genel anahtar ekleyebilirsiniz. Her genel anahtar yeni bir satırda olmalıdır. İşlemi tamamladıktan sonra dosyayı kaydedin ve kapatın.

      3. Dosya izinlerini ayarlayın.

        SSH sıkı izin ayarları gerektirir. Yanlış izinler SSH oturum açma işleminin başarısız olmasına neden olur.

        Doğru izinleri ayarlamak için aşağıdaki komutları çalıştırın.

        sudo chown -R <username>:<username> /home/<username>/.ssh
        sudo chmod 700 /home/<username>/.ssh
        sudo chmod 600 /home/<username>/.ssh/authorized_keys
    3. SSH hizmeti için genel anahtar kimlik doğrulamasını etkinleştirin.

      Genel anahtarı yapılandırdıktan sonra sunucuda SSH genel anahtar kimlik doğrulamasını etkinleştirmeniz gerekir. Aksi takdirde anahtar tabanlı oturum açma başarısız olur.

      1. SSH yapılandırma dosyasını /etc/ssh/sshd_config yedekleyin.

        sudo cp /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
      1. /etc/ssh/sshd_config dosyasını Vim gibi bir metin düzenleyiciyle açın. PubkeyAuthentication parametresini bulun ve yes olarak ayarlayın. Bu işlem genel anahtar kimlik doğrulamasını etkinleştirir.

        sudo vim /etc/ssh/sshd_config
      2. Değişikliklerin uygulanması için SSH hizmetini yeniden başlatın.

        Alibaba Cloud Linux 3 için örnek:

        sudo systemctl restart sshd
        Ubuntu veya Debian gibi bazı işletim sistemlerinde SSH hizmeti sshd yerine ssh olarak adlandırılır. Komutu gerektiği şekilde ayarlayın.
        Önemli

        Örneğe SSH üzerinden bağlıysanız hizmeti yeniden başlatmak bağlantınızı kesebilir. Hizmet yeniden başladıktan sonra tekrar bağlanabilirsiniz.

    Parola ayarlama

    Aşağıdaki komutu çalıştırın:

    <username> ifadesini parolasını değiştirmek istediğiniz kullanıcı adıyla değiştirin.
    sudo passwd <username>

    Yeni parolayı girin ve Enter tuşuna basın. Yeni parolayı tekrar girin ve Enter tuşuna basın.

    Parola başarıyla değiştirildikten sonra sistem aşağıdakine benzer bir mesaj görüntüler:

    passwd: all authentication tokens updated successfully.
  3. (Doğrulama) Yeni kullanıcı hesabıyla ECS örneğinde uzaktan oturum açma.

Windows sistemleri

Önemli

Varsayılan olarak Windows sistemleri Uzaktan Masaüstü Protokolü (RDP) aracılığıyla en fazla iki eşzamanlı uzaktan bağlantıyı destekler. Aynı anda bir Windows örneğinde ikiden fazla kullanıcının oturum açmasına izin vermek için Microsoft'un Uzaktan Masaüstü Hizmetleri özelliğini kullanmanız gerekir.

Workbench kullanarak örnekte oturum açın ve aşağıdaki adımları uygulayın:

  1. Kullanıcı oluşturma

    1. Denetim Masası'nı açın, User Accounts, öğesini bulun ve ardından Change account type. seçeneğine tıklayın.

    image

    1. Manage Accounts sayfasında Add a user account seçeneğine tıklayarak Add User sayfasına gidin.

    image

    1. Kullanıcı ekle sayfasında ekrandaki talimatları izleyerek yeni kullanıcı için kullanıcı adını ve parolayı ayarlayın.

      Bu örnekte exampleuser adlı bir kullanıcı oluşturulur. User Name değerini ihtiyaca göre ayarlayın.
    2. Next seçeneğine tıklayın ve ardından Complete seçeneğine tıklayın. Yeni kullanıcı oluşturulur.

    image

  2. Yeni kullanıcıyı Uzak Masaüstü Kullanıcıları grubuna ekleme

    Yalnızca Uzak Masaüstü Kullanıcıları grubundaki kullanıcılar örnekte uzaktan oturum açabilir.

    1. Görev çubuğundaki arama kutusunda Computer Management. arayın. Arama sonuçlarında Computer Management seçeneğine tıklayarak Computer Management sayfasını açın.

    image

    1. System tools > Local Users and Groups > altında Uzak Masaüstü Kullanıcıları grubunu bulun. Grubu açmak ve Remote Desktop Users Properties sayfasını açmak için üzerine çift tıklayın.

    image

    1. Yordam resimde gösterilmiştir.

      1. Remote Desktop Users Properties sayfasında Add seçeneğine tıklayın.

      2. Oluşturduğunuz kullanıcının kullanıcı adını girin ve ardından Check Names seçeneğine tıklayın. Kullanıcının tam adı metin kutusuna otomatik olarak girilir.

      3. OK seçeneğine tıklayın. Remote Desktop Users Properties sayfasında OK ve ardından OK seçeneğine tıklayın. Kullanıcı kullanıcı grubuna eklenir.

    image

  3. (Doğrulama) Yeni kullanıcı hesabıyla ECS örneğinde uzaktan oturum açma.

SSS

S1: Bir ECS örneği için varsayılan veya ilk oturum açma adı nedir?

  • Linux örnekleri için: Varsayılan root şeklindedir. Oluşturma sırasında örneği ecs-user kullanacak şekilde ayarlarsanız oturum açma adı ecs-user olur.

  • Windows örnekleri için: Varsayılan Administrator şeklindedir.

S2: Bir ECS örneği için varsayılan veya ilk parola nedir?

Yoktur.

Güvenlik nedenleriyle Alibaba Cloud ECS örnekleri için varsayılan veya ilk bir parola ayarlamaz. Örneği oluştururken bir parola ayarlamadıysanız bkz. Parolayı sıfırlama (orijinal parolayı bilmiyorsanız veya unuttuysanız).

S3: Örnek parolasını nasıl görüntüleyebilirim?

Alibaba Cloud örnek parolanızı kaydetmez; bu nedenle görüntülenemez.

S4: Oturum açma adımı veya parolamı unutursam kimlik bilgilerimi nasıl kurtarabilirim?

Unutulan oturum açma adı: Oturum açma adınızı bulmak için Parolayı Sıfırla özelliğini kullanın. Örneği oluştururken ayarladığınız oturum açma adı Örnek Parolasını Sıfırla iletişim kutusunun üst kısmında görünür.

Unutulan parola: Bkz. Parolayı sıfırlama (orijinal parolayı bilmiyorsanız veya unuttuysanız).

S5: Çevrimiçi parola sıfırlama neden başarısız olur?

Başarısızlıkların çoğu örnekteki güvenlik yazılımının parolayı değiştirmek için Cloud Assistant komutunu engellemesinden kaynaklanır. Bunun yerine çevrimdışı parola sıfırlama kullanın.

S6: "root" ve "ecs-user" arasında nasıl geçiş yapabilirim?

  • root'tan ecs-user'a geçiş

    Oturum açma adını yalnızca belirli Linux görüntüleri kullanarak özel yapılandırmayla bir örnek oluştururken ecs-user olarak ayarlayabilirsiniz.

    Bir örnek oluşturulduktan sonra oturum açma adını doğrudan ecs-user olarak değiştiremezsiniz. Ancak benzer bir sonuç elde edebilirsiniz. Uzaktan oturum açma için yeni bir kullanıcı ekleyin ve adına ecs-user verin, ardından bu kullanıcıya sudo izinleri verin.

  • ecs-user'dan root'a geçiş

    ecs-user kullanmaya devam etmenizi ve ayrıcalık gerektiren komutları sudo ile çalıştırmanızı önemle tavsiye ederiz. Doğrudan root kullanıcısı olarak oturum açmayın.

    Aktif bir oturumda root kullanıcısına geçmeniz gerekiyorsa örnekte ecs-user olarak oturum açın ve ardından sudo su komutunu çalıştırarak root kullanıcısına geçin.

Not: Konsoldaki çevrimdışı parola sıfırlama ve anahtar çifti iliştirme gibi özellikler yalnızca örnek oluşturulurken ayarlanan oturum açma adı için geçerlidir.

S7: Bir Linux örneğini hem SSH anahtar çifti hem de parola kimlik doğrulamasını destekleyecek şekilde nasıl etkinleştirebilirim?

SSH hizmeti için /etc/ssh/sshd_config yapılandırma dosyasını değiştirin.

  • SSH anahtar çifti kimlik doğrulamasını etkinleştirme (daha iyi güvenlik için önerilir): Bu seçenek PubkeyAuthentication tarafından kontrol edilir. Anahtar çifti kimlik doğrulamasını etkinleştirmek için bu seçeneği yes olarak ayarlayın. Yapılandırmayı değiştirdikten sonra örnekteki SSH hizmetini yeniden başlatın.

  • SSH parola kimlik doğrulamasını etkinleştirme (daha düşük güvenlik nedeniyle önerilmez): Bu seçenek PasswordAuthentication tarafından kontrol edilir. Parola kimlik doğrulamasını etkinleştirmek için bu seçeneği yes olarak ayarlayın. Yapılandırmayı değiştirdikten sonra örnekteki SSH hizmetini yeniden başlatın.

S8: Terraform ile bir örnek oluştururken ECS oturum açma adını nasıl ayarlarım?

Bir ECS örneği için varsayılan oturum açma adı görüntüsü tarafından belirlenir. Linux için varsayılan root, Windows için Administrator şeklindedir. Terraform kullanarak bir ECS örneği oluştururken image_options bloğunu ve login_as_non_root parametresini kullanarak root olmayan root bir oturum açma kullanıcısı yapılandırabilirsiniz.

  • Parametre: login_as_non_root (Boolean).

  • Değer: Bu parametreyi true olarak ayarlayın.

  • Sonuç: Örnek için oturum açma adı ecs-user olarak değişir.